@@ -22,6 +22,7 @@
 
 #include <e-util/e-util.h>
 
+#include "calendar-config.h"
 #include "comp-util.h"
 #include "e-comp-editor-property-part.h"
 
@@ -489,21 +490,44 @@ ecepp_string_fill_component (ECompEditorPropertyPart *property_part,
 	if (e_comp_editor_property_part_string_is_multivalue (E_COMP_EDITOR_PROPERTY_PART_STRING (property_part))) {
 		/* Clear all multivalues first */
 		e_cal_util_component_remove_property_by_kind (component, klass->prop_kind, TRUE);
-	}
 
-	prop = i_cal_component_get_first_property (component, klass->prop_kind);
+		if (value && *value) {
+			gchar **split_value;
 
-	if (value && *value) {
-		if (prop) {
-			klass->i_cal_set_func (prop, value);
+			split_value = g_strsplit (value, ",", -1);
+			if (split_value) {
+				gint ii;
+
+				/* Store multivalue properties into multiple properties,
+				   to workaround i_cal_component_clone() bug, which escapes
+				   commas in such properties. */
+				for (ii = 0; split_value[ii]; ii++) {
+					const gchar *item = split_value[ii];
+
+					if (*item) {
+						prop = klass->i_cal_new_func (item);
+						i_cal_component_take_property (component, prop);
+					}
+				}
+
+				g_strfreev (split_value);
+			}
+		}
+	} else {
+		prop = i_cal_component_get_first_property (component, klass->prop_kind);
+
+		if (value && *value) {
+			if (prop) {
+				klass->i_cal_set_func (prop, value);
+				g_object_unref (prop);
+			} else {
+				prop = klass->i_cal_new_func (value);
+				i_cal_component_take_property (component, prop);
+			}
+		} else if (prop) {
+			i_cal_component_remove_property (component, prop);
 			g_object_unref (prop);
-		} else {
-			prop = klass->i_cal_new_func (value);
-			i_cal_component_take_property (component, prop);
 		}
-	} else if (prop) {
-		i_cal_component_remove_property (component, prop);
-		g_object_unref (prop);
 	}
 
 	g_free (value);
@@ -606,6 +630,44 @@ ecepp_datetime_lookup_timezone (ECompEditorPropertyPartDatetime *part_datetime,
 	return zone;
 }
 
+static struct tm
+ecepp_datetime_get_current_time_cb (EDateEdit *date_edit,
+				    gpointer user_data)
+{
+	GWeakRef *weakref = user_data;
+	ECompEditorPropertyPartDatetime *part_datetime;
+	ICalTime *today = NULL;
+	struct tm tm;
+
+	memset (&tm, 0, sizeof (struct tm));
+
+	g_return_val_if_fail (weakref != NULL, tm);
+
+	part_datetime = g_weak_ref_get (weakref);
+	if (part_datetime) {
+		ETimezoneEntry *timezone_entry = g_weak_ref_get (&part_datetime->priv->timezone_entry);
+		ICalTimezone *editor_zone = NULL;
+
+		if (timezone_entry)
+			editor_zone = e_timezone_entry_get_timezone (timezone_entry);
+
+		if (editor_zone)
+			today = i_cal_time_new_current_with_zone (editor_zone);
+
+		g_clear_object (&timezone_entry);
+		g_object_unref (part_datetime);
+	}
+
+	if (!today)
+		today = i_cal_time_new_current_with_zone (calendar_config_get_icaltimezone ());
+
+	tm = e_cal_util_icaltime_to_tm (today);
+
+	g_clear_object (&today);
+
+	return tm;
+}
+
 static void
 ecepp_datetime_create_widgets (ECompEditorPropertyPart *property_part,
 			       GtkWidget **out_label_widget,
@@ -633,6 +695,10 @@ ecepp_datetime_create_widgets (ECompEditorPropertyPart *property_part,
 
 	gtk_widget_show (*out_edit_widget);
 
+	e_date_edit_set_get_time_callback (E_DATE_EDIT (*out_edit_widget),
+		ecepp_datetime_get_current_time_cb,
+		e_weak_ref_new (property_part), (GDestroyNotify) e_weak_ref_free);
+
 	g_signal_connect_swapped (*out_edit_widget, "changed",
 		G_CALLBACK (e_comp_editor_property_part_emit_changed), property_part);
 	g_signal_connect_swapped (*out_edit_widget, "notify::show-time",
@@ -993,10 +1059,19 @@ e_comp_editor_property_part_datetime_get_value (ECompEditorPropertyPartDatetime
 			i_cal_time_set_time (value, hour, minute, 0);
 
 			timezone_entry = g_weak_ref_get (&part_datetime->priv->timezone_entry);
-			if (timezone_entry)
-				i_cal_time_set_timezone (value, e_timezone_entry_get_timezone (timezone_entry));
-			if (!i_cal_time_get_timezone (value))
-				i_cal_time_set_timezone (value, i_cal_timezone_get_utc_timezone ());
+			if (timezone_entry) {
+				ICalTimezone *zone, *utc_zone;
+
+				utc_zone = i_cal_timezone_get_utc_timezone ();
+				zone = e_timezone_entry_get_timezone (timezone_entry);
+
+				/* It's required to have set the built-in UTC zone, not its copy,
+				   thus libical knows that it's a UTC time, not a time with UTC TZID. */
+				if (zone && g_strcmp0 (i_cal_timezone_get_location (utc_zone), i_cal_timezone_get_location (zone)) == 0)
+					zone = utc_zone;
+
+				i_cal_time_set_timezone (value, zone);
+			}
 		}
 	}
 
